@@ -9,6 +9,8 @@ from inelsmqtt import InelsMqtt
 from inelsmqtt.const import (
     DEVICE_TYPE_DICT,
     FRAGMENT_DOMAIN,
+    INELS_DEVICE_TYPE_DICT,
+    SENSOR,
     TOPIC_FRAGMENTS,
     FRAGMENT_DEVICE_TYPE,
     FRAGMENT_SERIAL_NUMBER,
@@ -47,10 +49,17 @@ class Device(object):
         self.__device_type = DEVICE_TYPE_DICT[
             fragments[TOPIC_FRAGMENTS[FRAGMENT_DEVICE_TYPE]]
         ]
+        self.__inels_type = INELS_DEVICE_TYPE_DICT[
+            fragments[TOPIC_FRAGMENTS[FRAGMENT_DEVICE_TYPE]]
+        ]
         self.__unique_id = fragments[TOPIC_FRAGMENTS[FRAGMENT_UNIQUE_ID]]
         self.__parent_id = fragments[TOPIC_FRAGMENTS[FRAGMENT_SERIAL_NUMBER]]
         self.__state_topic = state_topic
-        self.__set_topic = f"{fragments[TOPIC_FRAGMENTS[FRAGMENT_DOMAIN]]}/set/{fragments[TOPIC_FRAGMENTS[FRAGMENT_SERIAL_NUMBER]]}/{fragments[TOPIC_FRAGMENTS[FRAGMENT_DEVICE_TYPE]]}/{fragments[TOPIC_FRAGMENTS[FRAGMENT_UNIQUE_ID]]}"  # noqa: E501
+        self.__set_topic = None
+
+        if self.__device_type is not SENSOR:
+            self.__set_topic = f"{fragments[TOPIC_FRAGMENTS[FRAGMENT_DOMAIN]]}/set/{fragments[TOPIC_FRAGMENTS[FRAGMENT_SERIAL_NUMBER]]}/{fragments[TOPIC_FRAGMENTS[FRAGMENT_DEVICE_TYPE]]}/{fragments[TOPIC_FRAGMENTS[FRAGMENT_UNIQUE_ID]]}"  # noqa: E501
+
         self.__connected_topic = f"{fragments[TOPIC_FRAGMENTS[FRAGMENT_DOMAIN]]}/connected/{fragments[TOPIC_FRAGMENTS[FRAGMENT_SERIAL_NUMBER]]}/{fragments[TOPIC_FRAGMENTS[FRAGMENT_DEVICE_TYPE]]}/{fragments[TOPIC_FRAGMENTS[FRAGMENT_UNIQUE_ID]]}"  # noqa: E501
         self.__title = title if title is not None else self.__unique_id
         self.__domain = fragments[TOPIC_FRAGMENTS[FRAGMENT_DOMAIN]]
@@ -68,6 +77,15 @@ class Device(object):
         """
         return self.__unique_id
 
+    @property
+    def inels_type(self) -> str:
+        """Get inels type of the device
+
+        Returns:
+            str: Type
+        """
+        return self.__inels_type
+
     @property
     def device_type(self) -> str:
         """Get type of the device
@@ -139,6 +157,9 @@ class Device(object):
     @property
     def state(self) -> Any:
         """State of the device."""
+        if self.__state is None:
+            self.get_value()
+
         return self.__state
 
     def get_value(self) -> DeviceValue:
@@ -149,7 +170,9 @@ class Device(object):
         """
         val = self.__mqtt.messages.get(self.state_topic)
         dev_value = DeviceValue(
-            self.__device_type, inels_value=(val.decode() if val is not None else None)
+            self.__device_type,
+            self.__inels_type,
+            inels_value=(val.decode() if val is not None else None),
         )
 
         self.__state = dev_value.ha_value
@@ -165,11 +188,15 @@ class Device(object):
         Returns:
             true/false if publishing is successfull or not
         """
-        dev = DeviceValue(self.__device_type, ha_value=value)
+        dev = DeviceValue(self.__device_type, self.__inels_type, ha_value=value)
 
         self.__state = dev.ha_value
 
-        return self.__mqtt.publish(self.__set_topic, dev.inels_set_value)
+        ret = False
+        if self.__set_topic is not None:
+            ret = self.__mqtt.publish(self.__set_topic, dev.inels_set_value)
+
+        return ret
 
     def set_inels_value(self, value: str) -> bool:
         """Set the value into the broker
@@ -180,11 +207,15 @@ class Device(object):
         Returns:
             true/false if publishing is successfull or not
         """
-        dev = DeviceValue(self.__device_type, inels_value=value)
+        dev = DeviceValue(self.__device_type, self.__inels_type, inels_value=value)
 
         self.__state = dev.ha_value
 
-        return self.__mqtt.publish(self.__set_topic, dev.inels_set_value)
+        ret = False
+        if self.__set_topic is not None:
+            self.__mqtt.publish(self.__set_topic, dev.inels_set_value)
+
+        return ret
 
     def info(self):
         """Device info."""
