@@ -1,13 +1,20 @@
 """Utility classes."""
+from operator import itemgetter
 from typing import Any, Dict
 
 from inelsmqtt.mqtt_client import GetMessageType
 
 from .const import (
-    DEVICE_TYPE_DICT,
+    ANALOG_REGULATOR_SET_BYTES,
+    DEVICE_TYPE_05_DATA,
+    DEVICE_TYPE_05_HEX_VALUES,
+    DIMMER,
+    LIGHT,
+    SENSOR,
     SWITCH,
     SWITCH_SET,
     SWITCH_STATE,
+    TEMPERATURE,
 )
 
 ConfigType = Dict[str, str]
@@ -18,7 +25,8 @@ class DeviceValue(object):
 
     def __init__(
         self,
-        device_type: DEVICE_TYPE_DICT,
+        device_type: str,
+        inels_type: str,
         inels_value: str = None,
         ha_value: Any = None,
     ) -> None:
@@ -27,6 +35,7 @@ class DeviceValue(object):
         self.__inels_set_value: Any = None
         self.__ha_value = ha_value
         self.__device_type = device_type
+        self.__inels_type = inels_type
 
         if self.__ha_value is None:
             self.__find_ha_value()
@@ -36,17 +45,56 @@ class DeviceValue(object):
 
     def __find_ha_value(self) -> None:
         """Find and crete device value object."""
-        if self.__device_type == SWITCH:
+        if self.__device_type is SWITCH:
             self.__ha_value = SWITCH_STATE[self.__inels_status_value]
             self.__inels_set_value = SWITCH_SET[self.__ha_value]
+        elif self.__device_type is SENSOR:
+            if self.__inels_type is TEMPERATURE:
+                self.__ha_value = self.__inels_status_value
+            else:
+                self.__ha_value = self.__inels_status_value
+        elif self.__device_type is LIGHT:
+            if self.__inels_type is DIMMER:
+                self.__ha_value = DEVICE_TYPE_05_HEX_VALUES[self.__inels_status_value]
+
+                trimmed_data = self.__trim_inels_status_values(
+                    DEVICE_TYPE_05_DATA, DIMMER, " "
+                )
+                self.__inels_set_value = (
+                    f"{ANALOG_REGULATOR_SET_BYTES[DIMMER]} {trimmed_data}"
+                )
+            else:
+                self.__ha_value = self.__inels_status_value
+
+    def __trim_inels_status_values(
+        self, selector: dict[str, Any], fragment: str, jointer: str
+    ) -> str:
+        """Trim inels status from broker into the pure string."""
+        data = self.__inels_status_value.split("\n")[:-1]
+
+        selected = itemgetter(*selector[fragment])(data)
+
+        return jointer.join(selected)
 
     def __find_inels_value(self) -> None:
         """Find inels mqtt value for specific device."""
-        if self.__device_type == SWITCH:
+        if self.__device_type is SWITCH:
             self.__inels_status_value = self.__find_keys_by_value(
                 SWITCH_STATE, self.__ha_value
             )
             self.__inels_set_value = SWITCH_SET.get(self.__ha_value)
+        elif self.__device_type is LIGHT:
+            if self.__inels_type is DIMMER:
+                self.__inels_status_value = self.__find_keys_by_value(
+                    DEVICE_TYPE_05_HEX_VALUES, round(self.__ha_value, -1)
+                )
+                trimmed_data = self.__trim_inels_status_values(
+                    DEVICE_TYPE_05_DATA, DIMMER, " "
+                )
+                self.__inels_set_value = (
+                    f"{ANALOG_REGULATOR_SET_BYTES[DIMMER]} {trimmed_data}"
+                )
+                self.__ha_value = DEVICE_TYPE_05_HEX_VALUES[self.__inels_status_value]
 
     def __find_keys_by_value(self, array: dict, value) -> Any:
         """Return key from dict by value
